:mod:`jmap.objects` -- JMAP data objects
=========================================

.. automodule:: caldav.jmap.objects.calendar
   :members:

.. automodule:: caldav.jmap.objects.event
   :members:

.. automodule:: caldav.jmap.objects.task
   :members:

.. automodule:: caldav.jmap.error
   :members:
